@@ -1,4 +1,4 @@
-# Copyright 2021 Sebastian Ramacher <sebastian.ramacher@ait.ac.at>
+# Copyright 2021-2022 Sebastian Ramacher <sebastian.ramacher@ait.ac.at>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -19,7 +19,8 @@
 # SOFTWARE.
 
 import warnings
-from typing import Optional, Sequence
+from types import TracebackType
+from typing import Literal, Optional, Sequence, Type
 
 from ._relic import (
     # BN
@@ -56,10 +57,10 @@ from ._relic import (
     pair_product,
 )
 
-__version__ = "0.3"
+__version__ = "0.3.1"
 __author__ = "Sebastian Ramacher"
 __license__ = "MIT"
-__copyright__ = f"(C) 2021 {__author__}"
+__copyright__ = f"(C) 2021-2022 {__author__}"
 
 
 def _init() -> None:
@@ -87,8 +88,13 @@ class Relic:
     def __enter__(self) -> "Relic":
         return self
 
-    def __exit__(self, exc_type, exc_val, exc_tb) -> None:
-        pass
+    def __exit__(
+        self,
+        exc_type: Optional[Type[BaseException]],
+        exc_val: Optional[BaseException],
+        exc_tb: Optional[TracebackType],
+    ) -> Literal[False]:
+        return False
 
 
 def mul_sim_G1(
